@@ -1,5 +1,6 @@
 import os
 import sys
+import time
 from itertools import permutations
 import pickle
 from pydub import AudioSegment
@@ -41,6 +42,11 @@ def find_files(directory, pattern=['.wav']):
                 yield os.path.join(root, filename)
 
 
+def create_dir(dir_path):
+    if not os.path.exists(dir_path):
+        os.makedirs(dir_path)
+
+
 def create_overlapping_signal(signal1, signal2, read=False):
     '''
     Mix two signals in one
@@ -184,3 +190,31 @@ def mp3_to_wav(input_file, output_file, channels=1):
         )
     except:
         print('Can not transform mp3 to wav!')
+
+
+def clock():
+    try:
+        return time.perf_counter()  # Python 3
+    except:
+        return time.clock() # Python 2
+
+
+class Timer(object):
+    # Begin of `with` block
+    def __enter__(self):
+        self.start_time = clock()
+        self.end_time = None
+        return self
+
+    # End of `with` block
+    def __exit__(self, exc_type, exc_value, tb):
+        self.end_time = clock()
+
+    def elapsed_time(self):
+        """Return elapsed time in seconds"""
+        if self.end_time is None:
+            # still running
+            return clock() - self.start_time
+        else:
+            return self.end_time - self.start_time
+
